import { CronType, FieldWrapper, type CronSegment, type SegmentFromString } from './types';
declare class NoSpecificSegment implements CronSegment {
    field: FieldWrapper;
    type: CronType;
    constructor(field: FieldWrapper);
    toCron(): string;
    toArray(): never[];
    get items(): {};
    static fromString(str: string, field: FieldWrapper): NoSpecificSegment | null;
}
declare class AnySegment implements CronSegment {
    field: FieldWrapper;
    type: CronType;
    constructor(field: FieldWrapper);
    toCron(): string;
    toArray(): never[];
    get items(): {};
    static fromString(str: string, field: FieldWrapper): AnySegment | null;
    static fromArray(arr: number[], field: FieldWrapper): AnySegment | null;
}
declare class RangeSegment implements CronSegment {
    static re: RegExp;
    field: FieldWrapper;
    type: CronType;
    start: number;
    end: number;
    constructor(field: FieldWrapper, start: number, end: number);
    toCron(): string;
    toArray(): number[];
    get items(): {
        start: import("./types").FieldItem;
        end: import("./types").FieldItem;
    };
    static fromString(str: string, field: FieldWrapper): RangeSegment | null;
}
declare class EverySegment implements CronSegment {
    static re: RegExp;
    field: FieldWrapper;
    type: CronType;
    every: number;
    start: number;
    end: number;
    constructor(field: FieldWrapper, every: number, start?: number, end?: number);
    toCron(): string;
    toArray(): number[];
    get items(): {
        every: import("./types").FieldItem;
        start: import("./types").FieldItem;
        end: import("./types").FieldItem;
    };
    static fromString(str: string, field: FieldWrapper): EverySegment | null;
    static fromArray(arr: number[], field: FieldWrapper): EverySegment | null;
}
declare class ValueSegment implements CronSegment {
    field: FieldWrapper;
    type: CronType;
    value: number;
    constructor(field: FieldWrapper, value: number);
    toCron(): string;
    toArray(): number[];
    get items(): {
        value: import("./types").FieldItem;
    };
    static fromString(str: string, field: FieldWrapper): ValueSegment | null;
    static fromArray(arr: number[], field: FieldWrapper): number | null;
}
declare class CombinedSegment implements CronSegment {
    static segmentFactories: SegmentFromString[];
    field: FieldWrapper;
    segments: CronSegment[];
    constructor(field: FieldWrapper, segments?: CronSegment[]);
    get type(): CronType;
    addSegment(segment: CronSegment): void;
    toCron(): string;
    toArray(): number[];
    get items(): never;
    static fromString(str: string, field: FieldWrapper): CombinedSegment | null;
    static fromArray(arr: number[], field: FieldWrapper): CombinedSegment | null;
}
declare function cronToSegment(cron: string, field: FieldWrapper): CombinedSegment | null;
declare function arrayToSegment(arr: number[], field: FieldWrapper): CombinedSegment | AnySegment | EverySegment | null;
export { AnySegment, CombinedSegment, EverySegment, NoSpecificSegment, RangeSegment, ValueSegment, arrayToSegment, cronToSegment, };
//# sourceMappingURL=cron.d.ts.map